@@ -32,6 +32,7 @@
 #define USB_CLASS_COMM			2
 #define USB_CLASS_HID			3
 #define USB_CLASS_PRINTER		7
+#define USB_CLASS_PTP			6
 #define USB_CLASS_MASS_STORAGE		8
 #define USB_CLASS_HUB			9
 #define USB_CLASS_DATA			10
@@ -222,7 +223,7 @@ struct usb_ctrl_setup {
  * This is supposed to look weird. This file is generated from autoconf
  * and I didn't want to make this too complicated.
  */
-#if 1
+#if 0
 #define USB_LE16_TO_CPU(x) do { x = ((x & 0xff) << 8) | ((x & 0xff00) >> 8); } while(0)
 #else
 #define USB_LE16_TO_CPU(x)
